@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2007, 2012, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2013, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -215,49 +215,40 @@ bool WBComponentBasic::handles_figure(const model_ObjectRef &object)
 }
 
 
-
-grt::ValueRef WBComponentBasic::place_layer_grt(grt::GRT *grt, ModelDiagramForm *form,
-                                             const Rect &rect)
-{
-  model_DiagramRef view(form->get_model_diagram());
-
-  std::string color;
-
-  if (form->get_tool_argument("workbench.model.Layer:Color").empty())
-    color= _wb->get_wb_options().get_string("workbench.model.Layer:Color");
-  else
-    color= form->get_tool_argument("workbench.model.Layer:Color");
-
-  model_LayerRef layer;
-
-  grt::AutoUndo undo(grt);
-  
-  layer= view->placeNewLayer(rect.left(), rect.top(), rect.width(), rect.height(), _("New Layer"));
-
-  if (layer.is_valid())
-    layer->color(color);
-
-  undo.end(_("Place New Layer"));
-  
-  return layer;
-}
-
-
-void WBComponentBasic::place_layer(ModelDiagramForm *view, const Rect &rect)
+grt::ValueRef WBComponentBasic::place_layer(ModelDiagramForm *form, const Rect &rect)
 {
   try
   {
-    _wb->execute_in_grt_thread("Place new layer in model",
-                        boost::bind(&WBComponentBasic::place_layer_grt, this, _1, view, rect));
+    model_DiagramRef view(form->get_model_diagram());
+
+    std::string color;
+
+    if (form->get_tool_argument("workbench.model.Layer:Color").empty())
+      color= _wb->get_wb_options().get_string("workbench.model.Layer:Color");
+    else
+      color= form->get_tool_argument("workbench.model.Layer:Color");
+
+    model_LayerRef layer;
+
+    grt::AutoUndo undo(get_grt());
+  
+    layer= view->placeNewLayer(rect.left(), rect.top(), rect.width(), rect.height(), _("New Layer"));
+
+    if (layer.is_valid())
+      layer->color(color);
+
+    undo.end(_("Place New Layer"));
+  
     _wb->show_status_text(_("Created new layer."));
+    return layer;
   }
   catch (std::exception &exc)
   {
     _wb->show_exception(_("Place new layer"), exc);
+    return grt::ValueRef();
   }
 }
 
-
 //-------------------------------------------------------------------------------------
 // Deletion
 
