@@ -292,8 +292,7 @@ void WorkbenchCentral::repaint(cairo_t* cr, int areax, int areay, int areaw, int
       extra_offset= remaining_space / starter_count;
       remaining_space= available_width - extra_offset * starter_count;
 
-      for (std::vector<StarterEntry>::iterator iterator= _starters.begin(); 
-        iterator != _starters.end(), starter_count > 0; iterator++)
+      for (std::vector<StarterEntry>::iterator iterator= _starters.begin(); starter_count > 0; iterator++)
       {
         // Store final position of the starter for later hit tests.
         iterator->bounds.pos.x = current_offset;
@@ -1376,39 +1375,41 @@ void ActionLinkBox::mouse_click(int button, int x, int y)
   // Passes the call to the action link
   ActionLink* link= action_link_from_point(x, y);
 
-  switch (button)
-  {
-    case MouseButtonLeft:
+  if (link)
+  {  
+    switch (button)
     {
-      if (link)
+      case MouseButtonLeft:
+      {
         link->mouse_click(button, x, y);
-      
-      if (_single_click)
-      {
-        if (link == _selected_link)
+        
+        if (_single_click)
         {
-          for (int index= 0; index < (int) _links.size(); index++)
-            if (_links[index] == _selected_link)
-            {
-              _owner->trigger_callback(link->get_action(), link->get_object());
-              return;
-            }
+          if (link == _selected_link)
+          {
+            for (int index= 0; index < (int) _links.size(); index++)
+              if (_links[index] == _selected_link)
+              {
+                _owner->trigger_callback(link->get_action(), link->get_object());
+                return;
+              }
+          }
         }
-      }
-      break;
-    } 
-    case MouseButtonRight:
-      if (_selected_link != NULL)
-      {
-        if (link->get_type() == GroupLink)
+        break;
+      } 
+      case MouseButtonRight:
+        if (_selected_link != NULL)
         {
-          if (_group_context_menu != NULL)
-            _group_context_menu->popup_at(this, x + 5, y + 5);
+          if (link->get_type() == GroupLink)
+          {
+            if (_group_context_menu != NULL)
+              _group_context_menu->popup_at(this, x + 5, y + 5);
+          }
+          else if (_context_menu != NULL)
+            _context_menu->popup_at(this, x + 5, y + 5);
         }
-        else if (_context_menu != NULL)
-          _context_menu->popup_at(this, x + 5, y + 5);
-      }
-      break;
+        break;
+    }
   }
 }
 
@@ -1418,6 +1419,7 @@ void ActionLinkBox::mouse_double_click(int button, int x, int y)
 {
   ActionLink* link= action_link_from_point(x, y);
       
+    
   switch (button)
   {
     case MouseButtonLeft:
@@ -1767,8 +1769,7 @@ void ActionList::set_collapsed_groups(std::string collapsed_groups)
 {
   std::vector<std::string> groups = base::split(collapsed_groups, "/");
   
-  for(std::vector<std::string>::iterator end = groups.end(),
-      group = groups.begin(); group != groups.end(); group++)
+  for(std::vector<std::string>::iterator group = groups.begin(); group != groups.end(); group++)
   {
     _link_group_state[*group] = false;
   }
