@@ -164,7 +164,7 @@ namespace wb
   public:
     ActionLink(cairo_surface_t *icon, const std::string& title, const std::string& description,
                const grt::ValueRef &object, HomeScreenAction action, bool enabled, ActionLinkType type = NormalLink);
-    ~ActionLink();
+    virtual ~ActionLink();
     
     virtual void paint(cairo_t* cr, base::Rect bounds, bool hot, bool active);
     bool contains(double x, double y);
