@@ -18,9 +18,9 @@
  */
 
 #include "tut_stdafx.h"
-// High-level testing for Workbench
-// This tests WBContext, which will test the integration of all
-// components
+
+// High-level testing for Workbench.
+// This tests WBContext, which will test the integration of all components.
 
 #include "wb_helpers.h"
 #include "workbench/wb_overview.h"
@@ -35,16 +35,13 @@
 
 using namespace wb;
 
-BEGIN_TEST_DATA_CLASS(wb_lowlevel)
+BEGIN_TEST_DATA_CLASS(wb_lowlevel_test)
 
 END_TEST_DATA_CLASS;
 
+TEST_MODULE(wb_lowlevel_test, "Low-level tests for Workbench context");
 
-
-TEST_MODULE(wb_lowlevel, "low-level tests for Workbench context");
-
-
-TEST_FUNCTION(2)
+TEST_FUNCTION(5)
 {
   // Check that loaded connections file correctly sets the driver link.
   // Create a connections config file from the template first.
@@ -68,14 +65,12 @@ TEST_FUNCTION(2)
     tester.wb->get_root()->rdbmsMgmt()->storedConns().get(0)->driver().is_valid());
 }
 
-
-
-
-TEST_FUNCTION(3)
+TEST_FUNCTION(10)
 {
   // check if creating a fk between 2 tables will create the connection
 
   WBTester tester;
+  populate_grt(tester.grt, NULL, tester);
 
   tester.wb->new_document();
   tester.add_view();
@@ -132,13 +127,11 @@ TEST_FUNCTION(3)
   ensure_equals("connection created", tester.get_pview()->connections().count(), 1U);
 }
 
-
-
-TEST_FUNCTION(4)
+TEST_FUNCTION(15)
 {
   // bug: check if creating a recursive fk will create the connection
-
   WBTester tester;
+  populate_grt(tester.grt, NULL, tester);
 
   tester.wb->new_document();
   tester.add_view();
@@ -175,7 +168,7 @@ TEST_FUNCTION(4)
 
 // TODO : Check if this function still valid as the function has been removed from WBContext
 /*
-TEST_FUNCTION(5)
+TEST_FUNCTION(20)
 {
   // test check_plugin_input_available from WBContext
   WBTester tester;
@@ -279,17 +272,17 @@ TEST_FUNCTION(5)
   ensure("workbench.physical.Model", wb->check_plugin_input_available(pdef));
 }*/
 
-
-
-TEST_FUNCTION(6)
+TEST_FUNCTION(25)
 {
   // bug: check if deleting an object with privileges will delete the privs too
 
   WBTester tester;
+  populate_grt(tester.grt, NULL, tester);
+
   tester.create_new_document();
 
   WBComponentPhysical *phys= tester.wb->get_component<WBComponentPhysical>();
-
+  ensure_equals("initial role count", tester.get_pmodel()->catalog()->roles().count(), 5U);
   phys->add_new_role(tester.get_pmodel());
   phys->add_new_role(tester.get_pmodel());
 
@@ -299,10 +292,10 @@ TEST_FUNCTION(6)
   phys->add_new_db_table(schema);
 
   ensure_equals("tables created", schema->tables().count(), 2U);
-  ensure_equals("roles created", tester.get_pmodel()->catalog()->roles().count(), 2U);
+  ensure_equals("roles created", tester.get_pmodel()->catalog()->roles().count(), 2U+5);
 
   // add some privs to the table
-  db_RoleRef role(tester.get_pmodel()->catalog()->roles().get(0));
+  db_RoleRef role(tester.get_pmodel()->catalog()->roles().get(5));
   db_TableRef table(schema->tables().get(0));
   db_TableRef table2(schema->tables().get(1));
 
@@ -332,29 +325,30 @@ TEST_FUNCTION(6)
   phys->delete_db_object(table);
 
   ensure_equals("tables left", tester.get_pmodel()->catalog()->schemata()[0]->tables().count(), 1U);
-  ensure_equals("roles left", tester.get_pmodel()->catalog()->roles().count(), 2U);
+  ensure_equals("roles left", tester.get_pmodel()->catalog()->roles().count(), 2U+5);
 
   ensure_equals("privs left", role->privileges().count(), 1U);
 
   ensure("priv owner", role->privileges().get(0)->databaseObject() == table2);
 }
 
-
-TEST_FUNCTION(7)
+TEST_FUNCTION(30)
 {
   WBTester tester;
+  populate_grt(tester.grt, NULL, tester);
+
   tester.create_new_document();
 
   // bug: undo drop table will not reset TableFigure::table_figure_for_dbtable()
 
   db_TableRef table;
-  workbench_physical_DiagramRef view;
 
   tester.wb->open_document("data/workbench/2tables_1fk.mwb");
-  ensure("load doc", tester.wb->get_document().is_valid());
-  tester.add_view();
+  workbench_DocumentRef doc = tester.wb->get_document();
+  ensure("load doc", doc.is_valid());
+ 
+  tester.open_all_diagrams();
 
-  tester.sync_view();
   ensure_equals("loaded 1 schema", tester.get_catalog()->schemata().count(), 1);
 
   std::list<db_DatabaseObjectRef> objects;
@@ -362,11 +356,10 @@ TEST_FUNCTION(7)
   objects.push_back(grt::find_named_object_in_list(tester.get_schema()->tables(), "table1"));
   ensure("found table", objects.front().is_valid());
   ensure_equals("found correct table", *objects.front()->name(), "table1");
-
+  ensure_equals("diagram count", doc->physicalModels()[0]->diagrams().count(), 1U);
   tester.interactive_place_db_objects(10, 150, objects);
 
   tester.flush_until(2);
-
   ensure_equals("check table", tester.get_pview()->figures().count(), 1U);
 
   tester.grt->get_undo_manager()->undo();
@@ -376,6 +369,4 @@ TEST_FUNCTION(7)
 
 
 
-
-
 END_TESTS
