@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2011, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2011, 2012 Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -115,8 +115,17 @@ TEST_FUNCTION(2)
 
   ModelFile m(tmpDir);
 
-  for (int i= 0; i < 10; i++)
+  m.open("data/workbench/sakila.mwb", grtm);
+
+  try
+  {
     m.open("data/workbench/sakila.mwb", grtm);
+    fail("open model file locking didnt work");
+  }
+  catch (...)
+  {
+    ensure("locking works", true);
+  }
 }
 
 TEST_FUNCTION(3)
