@@ -64,7 +64,6 @@ WorkbenchImpl::WorkbenchImpl(CPPModuleLoader *loader)
   _last_wmi_session_id= 1;
   _last_wmi_monitor_id= 1;
 #endif
-  _current_user_type_editor= NULL;
 }
 
 //--------------------------------------------------------------------------------------------------
@@ -1252,12 +1251,8 @@ std::string WorkbenchImpl::requestFileSave(const std::string &caption, const std
 
 int WorkbenchImpl::showUserTypeEditor(const workbench_physical_ModelRef &model)
 {
-  if ( _current_user_type_editor == NULL)
-  {
-    _current_user_type_editor = new UserDefinedTypeEditor(_wb->get_ui(), model);
-    scoped_connect(_current_user_type_editor->signal_closed(),boost::bind(&WorkbenchImpl::userTypeEditorClosed, this));
-  }
-  _current_user_type_editor->show_modal(NULL, NULL);
+  if (_wb->get_model_context())
+    _wb->get_model_context()->show_user_type_editor(model);
   
   return 0;
 }
@@ -1286,14 +1281,6 @@ int WorkbenchImpl::openGRTFile()
   return 0;
 }
 
-/**
- * Called by the front end when the user data type editor has been closed. We can then remove our reference to it.
- */
-void WorkbenchImpl::userTypeEditorClosed()
-{
-  _current_user_type_editor= NULL;
-}
-
 int WorkbenchImpl::showDocumentProperties()
 {
   DocumentPropertiesForm props(_wb->get_ui());
