@@ -49,7 +49,7 @@ ConfirmSaveDialog::ConfirmSaveDialog(mforms::Form *owner,
     _cancel_button.set_text(("Cancel"));
     discard->set_text(("Discard Changes"));
   
-    discard->signal_clicked().connect(sigc::mem_fun(this, &ConfirmSaveDialog::discard_clicked));
+    scoped_connect(discard->signal_clicked(),boost::bind(&ConfirmSaveDialog::discard_clicked, this));
 #ifdef __APPLE__
     bbox->add(discard, false, true);
     bbox->add_end(&_review_button, false, true);
