@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2008, 2010, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2008, 2011, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -19,8 +19,12 @@
 
 #include "stdafx.h"
 #include "grtdb_connect_dialog.h"
+
 #include "base/string_utilities.h"
 
+#include "mforms/uistyle.h"
+#include "mforms/utilities.h"
+
 using namespace grtui;
 
 DbConnectionDialog::DbConnectionDialog(const db_mgmt_ManagementRef &mgmt)
