@@ -48,7 +48,7 @@ WizardSchemaFilterPage::WizardSchemaFilterPage(WizardForm *form, const char *nam
     
   add(&_check_list, true, true);
 
-  _check_list.signal_changed().connect(sigc::mem_fun(this, &WizardSchemaFilterPage::validate));
+  scoped_connect(_check_list.signal_changed(),boost::bind(&WizardSchemaFilterPage::validate, this));
 }
  
 
