@@ -31,13 +31,13 @@
 #include "grt/grt_manager.h"
 
 
-class WBPUBLICBACKEND_PUBLIC_FUNC BridgeBase : public sigc::trackable
+class WBPUBLICBACKEND_PUBLIC_FUNC BridgeBase : public base::trackable
 {
 protected:
   bec::GRTManager *get_grtm() { return bec::GRTManager::get_instance_for(get_object()->get_grt()); }
   
-  void run_later(const sigc::slot<void> &slot);
-  static void run_later(grt::GRT *grt, const sigc::slot<void> &slot);
+  void run_later(const boost::function<void ()> &slot);
+  static void run_later(grt::GRT *grt, const boost::function<void ()> &slot);
   
 
   virtual GrtObject *get_object()= 0;
