@@ -457,7 +457,7 @@ void BaseFigure::invalidate_min_sizes()
 bool BaseFigure::on_drag_handle(mdc::ItemHandle *handle, const Point &pos, bool dragging)
 {
   if (!_manual_resizing)
-    set_allow_manual_resizing(true);
+    set_allow_manual_resizing(true); // TODO: what about undo record?
 
   if (dragging)
   {
@@ -470,8 +470,8 @@ bool BaseFigure::on_drag_handle(mdc::ItemHandle *handle, const Point &pos, bool
 
   if (!dragging)
   {
-    _resizing= false;
-    _signal_resize(_initial_bounds);
+    _resizing = false;
+    _signal_interactive_resize(_initial_bounds);
   }
   if (flag)
     set_fixed_size(get_size());
