@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2007, 2010, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2012, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -23,29 +23,24 @@
 
 
 #include "sqlide/var_grid_model_be.h"
-#include "GrtThreadedTask.h" // reference in stdafx.h is not enough because stdafx.h has subdir only effect
+#include "GrtThreadedTaskWrapper.h" // reference in stdafx.h is not enough because stdafx.h has subdir only effect
 
 
 namespace MySQL {
 namespace Grt {
 
 
-using namespace System;
-using namespace System::Runtime::InteropServices;
-using namespace System::Collections::Generic;
-
-
-public ref class VarGridModel : public MySQL::Grt::GridModel
+public ref class VarGridModelWrapper : public MySQL::Grt::GridModel
 {
 public:
   typedef ManagedRef<::VarGridModel> ^ Ref;
-  VarGridModel(Ref ref);
-  VarGridModel(IntPtr nref_ptr);
+  VarGridModelWrapper(Ref ref);
+  VarGridModelWrapper(IntPtr nref_ptr);
   Ref ref() { return _ref; }
 private:
   Ref _ref;
 private:
-  ~VarGridModel();
+  ~VarGridModelWrapper();
 
 public:
   typedef DelegateSlot0<int, int> Refresh_ui_cb;
