@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2008, 2012, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2008, 2013, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -114,15 +114,6 @@ namespace MySQL {
         return managed_shell; 
       }
 
-      // grt internal state inspectors
-      GrtValueTree^ get_shared_value_tree(String ^valuespec)
-      { return gcnew GrtValueTree(inner->get_shared_value_tree(NativeToCppString(valuespec))); }
-
-      GrtValueInspector^ get_new_value_inspector(GrtValue^ value, bool process_editas_flag)
-      {
-        return gcnew GrtValueInspector(inner->get_new_value_inspector(value->get_unmanaged_object(), process_editas_flag), false);
-      }
-
       void terminate() { inner->terminate(); };
       bool terminated() { return inner->terminated(); };
       void resetTermination() { inner->reset_termination(); };
