@@ -1,15 +1,30 @@
 /*
-   Copyright (c) 2009, 2010, Oracle and/or its affiliates. All rights reserved.
+Copyright (c) 2009, 2011, Oracle and/or its affiliates. All rights reserved.
 
-   The MySQL Connector/C++ is licensed under the terms of the GPL
-   <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most
-   MySQL Connectors. There are special exceptions to the terms and
-   conditions of the GPL as it is applied to this software, see the
-   FLOSS License Exception
-   <http://www.mysql.com/about/legal/licensing/foss-exception.html>.
+The MySQL Connector/C++ is licensed under the terms of the GPLv2
+<http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most
+MySQL Connectors. There are special exceptions to the terms and
+conditions of the GPLv2 as it is applied to this software, see the
+FLOSS License Exception
+<http://www.mysql.com/about/legal/licensing/foss-exception.html>.
+
+This program is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published
+by the Free Software Foundation; version 2 of the License.
+
+This program is distributed in the hope that it will be useful, but
+WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
+for more details.
+
+You should have received a copy of the GNU General Public License along
+with this program; if not, write to the Free Software Foundation, Inc.,
+51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
 */
 
 
+
+
 #include "libmysql_dynamic_proxy.h"
 
 #include <cppconn/exception.h>
@@ -427,7 +442,7 @@ LibmysqlDynamicProxy::real_connect(MYSQL * mysql,
 unsigned long
 LibmysqlDynamicProxy::real_escape_string(MYSQL * mysql, char * to, const char * from, unsigned long length)
 {
-	ptr2mysql_realescapestring ptr2_realescapestring = symbol_safe_cast<ptr2mysql_realescapestring>(GetProcAddr("mysql_real_escape_string"));
+	ptr2mysql_real_escape_string ptr2_realescapestring = symbol_safe_cast<ptr2mysql_real_escape_string>(GetProcAddr("mysql_real_escape_string"));
 
 	return (*ptr2_realescapestring)(mysql, to, from, length);
 }
@@ -505,6 +520,17 @@ LibmysqlDynamicProxy::use_result(MYSQL * mysql)
 /* }}} */
 
 
+/* {{{ LibmysqlDynamicProxy::warning_count() */
+unsigned int
+LibmysqlDynamicProxy::warning_count(MYSQL * mysql)
+{
+  ptr2mysql_warning_count ptr2_warning_count= symbol_safe_cast<ptr2mysql_warning_count>(GetProcAddr("mysql_warning_count"));
+
+	return (*ptr2_warning_count)(mysql);
+}
+/* }}} */
+
+
 /* Prepared Statement mysql_stmt_* functions */
 
 /* {{{ LibmysqlDynamicProxy::stmt_affected_rows() */
