@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 #
-# Copyright (c) 2012, Oracle and/or its affiliates. All rights reserved.
+# Copyright (c) 2012, 2013, Oracle and/or its affiliates. All rights reserved.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -67,9 +67,10 @@ add_failover_options(parser)
 # Connect information for candidate server for switchover
 parser.add_option("--new-master", action="store", dest="new_master", default=None,
                   type="string", help="connection information for the "
-                  "slave to be used to replace the master for switchover "
-                  "in the form: <user>:<password>@<host>:<port>:<socket>. "
-                  "Valid only with switchover command.")
+                  "slave to be used to replace the master for switchover, "
+                  "in the form: <user>[:<password>]@<host>[:<port>][:<socket>]"
+                  " or <login-path>[:<port>][:<socket>]. Valid only with "
+                  "switchover command.")
 
 # Force
 parser.add_option("--force", action="store_true", dest="force",
@@ -96,6 +97,11 @@ add_rpl_user(parser, None)
 # Now we process the rest of the arguments.
 opt, args = parser.parse_args()
 
+# At least one of the options --discover-slaves-login or --slaves is required.
+if not opt.discover and not opt.slaves:
+    parser.error("One of these options is required to use the utility: "
+                 "--discover-slaves-login or --slaves.")
+
 # Check slaves list
 check_server_lists(parser, opt.master, opt.slaves)
 
@@ -105,6 +111,13 @@ if len(args) > 1:
 elif len(args) == 0:
     parser.error("You must specify a command to execute.")
 
+# The value for --timeout needs to be an integer > 0.
+try:
+    if int(opt.timeout) <= 0:
+        parser.error("The --timeout option requires a value greater than 0.")
+except ValueError:
+    parser.error("The --timeout option requires an integer value.")
+
 # Check errors and warnings of options and combinations.
     
 command = args[0].lower()
@@ -156,9 +169,11 @@ if opt.format and command not in ['health', 'gtid']:
         
 if opt.new_master:
     try:
-        new_master_val = parse_connection(opt.new_master)
+        new_master_val = parse_connection(opt.new_master, None, opt)
     except FormatError, e:
         parser.error("New master connection values invalid or cannot be parsed.")
+    except UtilError as err:
+        parser.error(err.errmsg)
 else:
     new_master_val = None
 
@@ -191,7 +206,7 @@ options = {
     'max_position' : opt.max_position,
     'max_delay'    : opt.max_delay,
     'discover'     : opt.discover,
-    'timeout'      : opt.timeout,
+    'timeout'      : int(opt.timeout),
     'demote'       : opt.demote,
     'quiet'        : opt.quiet,
     'logging'      : opt.log_file is not None,
