@@ -329,6 +329,7 @@ const CGFloat paddingHighlightY = 2;
 
 - (void) dealloc
 {
+  [[NSNotificationCenter defaultCenter] removeObserver: self];
   [notificationQueue release];
   [super dealloc];
 }
@@ -381,8 +382,7 @@ const CGFloat paddingHighlightY = 2;
 
 ScintillaCocoa::ScintillaCocoa(NSView* view)
 {
-  //wMain= [view retain];// Don't retain since we're owned by view, which would cause a cycle
-  wMain = view;
+  wMain = view; // Don't retain since we're owned by view, which would cause a cycle
   timerTarget = [[TimerTarget alloc] init: this];
   layerFindIndicator = NULL;
   Initialise();
@@ -394,9 +394,6 @@ ScintillaCocoa::~ScintillaCocoa()
 {
   SetTicking(false);
   [timerTarget release];
-  //container is no longer retained as usual pattern is that container owns content, not the opposite
-  //NSView* container = ContentView();
-  //[container release];
 }
 
 //--------------------------------------------------------------------------------------------------
@@ -1524,7 +1521,8 @@ void ScintillaCocoa::SetVerticalScrollPos()
   
   // Convert absolute coordinate into the range [0..1]. Keep in mind that the visible area
   // does *not* belong to the scroll range.
-  float relativePosition = (float) topLine / MaxScrollPos();
+  int maxScrollPos = MaxScrollPos();
+  float relativePosition = (maxScrollPos > 0) ? ((float) topLine / maxScrollPos) : 0.0f;
   [topContainer setVerticalScrollPosition: relativePosition];
 }
 
