@@ -1,7 +1,8 @@
 #include "sqlide/grid_view_model.h"
 #include "sqlide/grid_view.h"
 #include "linux_utilities/gtk_helpers.h"
-#include "linux_utilities/custom_renderers.h"
+#include "custom_renderers.h"
+#include "base/string_utilities.h"
 
 GridViewModel::Ref GridViewModel::create(bec::GridModel::Ref model, GridView *view, const std::string &name)
 {
@@ -68,7 +69,8 @@ int GridViewModel::refresh(bool reset_columns)
       if (_row_numbers_visible)
       {
         Gtk::TreeViewColumn *col= add_column<ValueTypeTraits<> >(-2, "#", RO, NULL);
-        (*col->get_cell_renderers().begin())->property_cell_background()= "LightGray";
+        col->get_first_cell_renderer()->property_cell_background()= "LightGray";
+        col->set_min_width(30);
       }
     }
 
@@ -76,7 +78,7 @@ int GridViewModel::refresh(bool reset_columns)
     for (int index= 0, count= _model->get_column_count(); index < count; ++index)
     {
       Editable is_col_editable= (is_model_editable && (bec::GridModel::BlobType != _model->get_column_type(index))) ? EDITABLE : RO;
-      std::string label= bec::replace_string(_model->get_column_caption(index), "_", "__");
+      std::string label= bec::replace_string(base::sanitize_utf8(_model->get_column_caption(index)), "_", "__");
       bec::GridModel::ColumnType type= _model->get_column_type(index);
       Gtk::TreeViewColumn *col;
       switch (type)
@@ -90,7 +92,7 @@ int GridViewModel::refresh(bool reset_columns)
         col->set_min_width(30);
         break;
       default:
-        col = add_column<ValueTypeTraits<> >(index, label, is_col_editable, 0);
+        col = add_column<ValueTypeTraits<bec::GridModel::StringType> >(index, label, is_col_editable, 0);
         col->set_min_width(80);
         break;
       }
@@ -108,14 +110,14 @@ Gtk::TreeViewColumn * GridViewModel::add_column(int index, const std::string &na
   typedef Gtk::TreeModelColumn<typename ValueTypeTraits::ValueType> ModelColumn;
   ModelColumn *col = new ModelColumn();
   columns.add_model_column(col, index);
-  Gtk::TreeModelColumn<Glib::RefPtr<Gdk::Pixbuf> > *icon= new Gtk::TreeModelColumn<Glib::RefPtr<Gdk::Pixbuf> >();
+  Gtk::TreeModelColumn<Glib::RefPtr<Gdk::Pixbuf> > *icon = new Gtk::TreeModelColumn<Glib::RefPtr<Gdk::Pixbuf> >();
   columns.add_model_column(icon, index);
 
-  typedef Gtk::CustomRenderer<typename ValueTypeTraits::Renderer, typename ValueTypeTraits::RendererValueType, typename ValueTypeTraits::ValueType> CustomRenderer;
-  CustomRenderer *renderer= new CustomRenderer();
+  typedef CustomRenderer<typename ValueTypeTraits::Renderer, typename ValueTypeTraits::RendererValueType, typename ValueTypeTraits::ValueType> CustomRenderer;
+  CustomRenderer *renderer= Gtk::manage(new CustomRenderer());
   renderer->floating_point_visible_scale(_model->floating_point_visible_scale());
   renderer->set_edit_state= sigc::bind(sigc::mem_fun(_model.get(), &::bec::GridModel::set_edited_field), index);
-  Gtk::TreeViewColumn *treeview_column= renderer->bind_columns(_treeview, name, col, icon);
+  Gtk::TreeViewColumn *treeview_column= renderer->bind_columns(_view, name, index, col, icon);
   if (index >= 0 || index == -2)
   {
     treeview_column->signal_clicked().connect(sigc::bind(sigc::mem_fun(_view, &GridView::on_column_header_clicked), treeview_column, index));
@@ -124,16 +126,52 @@ Gtk::TreeViewColumn * GridViewModel::add_column(int index, const std::string &na
   if (color_column)
     treeview_column->add_attribute(renderer->property_cell_background_gdk(), *color_column);
   _col_index_map[treeview_column]= index;
+// XXX This causes the column auto-sizing to not work well. Enable it back once the auto-sizing is fixed.
+//  set_ellipsize(index, true);
   if (editable == EDITABLE)
   {
     renderer->property_editable()= true;
     renderer->signal_edited().connect(sigc::bind(sigc::mem_fun(*this, &GridViewModel::after_cell_edit<typename ValueTypeTraits::ValueType>), sigc::ref(*col)));
-    renderer->signal_edited().connect(_view->slot_cell_edited());
+    renderer->signal_edited().connect(sigc::mem_fun(_view, &GridView::on_cell_edited));
+    renderer->signal_editing_started().connect(sigc::bind(sigc::mem_fun(_view, &GridView::on_cell_editing_started), treeview_column));
+    renderer->signal_editing_canceled().connect(sigc::mem_fun(_view, &GridView::on_cell_editing_done));
   }
 
   return treeview_column;
 }
 
+void GridViewModel::set_ellipsize(const int column, const bool on)
+{
+  Gtk::TreeViewColumn *col = 0;
+  for(std::map<Gtk::TreeViewColumn*, int>::const_iterator end = _col_index_map.end(), it = _col_index_map.begin();
+      it != end;
+      ++it)
+  {
+    if (it->second == column)
+    {
+      col = it->first;
+      break;
+    }
+  }
+
+  if (col)
+  {
+    const std::vector<Gtk::CellRenderer*> rends = col->get_cell_renderers();
+    const int rends_size = rends.size();
+    for (int i = 0; i < rends_size; ++i)
+    {
+      CustomRendererOps* cr = dynamic_cast<CustomRendererOps*>(rends[i]);
+      if (cr)
+      {
+        Gtk::CellRendererText* crt = dynamic_cast<Gtk::CellRendererText*>(cr->data_renderer());
+        crt->property_ellipsize() = on ? Pango::ELLIPSIZE_END : Pango::ELLIPSIZE_NONE;
+        crt->property_ellipsize_set() = on;
+      }
+    }
+  }
+}
+
+
 int GridViewModel::column_index(Gtk::TreeViewColumn* col)
 {
   std::map<Gtk::TreeViewColumn*, int>::const_iterator i= _col_index_map.find(col);
@@ -185,3 +223,9 @@ bool GridViewModel::handle_popup_event(GdkEvent* event)
 {
   return false;
 }
+
+void GridViewModel::get_value_vfunc(const iterator& iter, int column, Glib::ValueBase& value) const
+{
+  ListModelWrapper::get_value_vfunc(iter, column, value);
+  before_render(column, &value);
+}
