@@ -109,7 +109,9 @@ static int processTaskMessage(int msgType, const std::string &message, const std
 
 static int onRefreshWhenIdle(MResultsetViewer *self)
 {
-  if (!self->mPendingRefresh)
+  // Do table refresh only if it isn't currently in edit mode or this will
+  // stop any ongoing edit action (and has other side effects like a misplaced selection).
+  if (!self->mPendingRefresh && [self->mTableView editedRow] == -1)
   {
     self->mPendingRefresh = YES;
     [self performSelector: @selector(refreshGrid) withObject:nil afterDelay: 0];
