@@ -27,10 +27,12 @@
 #import "GRTIconCache.h"
 
 #include "workbench/wb_context_ui.h"
-#include "workbench/wb_history_tree.h"
+#include "model/wb_history_tree.h"
 #include "model/wb_model_diagram_form.h"
 #include "model/wb_user_datatypes.h"
+#include "model/wb_context_model.h"
 
+#import "mforms/../cocoa/MFView.h"
 #import "MCPPUtilities.h"
 
 #include "grtdb/db_object_helpers.h"
@@ -38,9 +40,6 @@
 
 @implementation WBModelSidebarController
 
-static void refresh_history(const bec::NodeId &parent, int orow, WBModelSidebarController *self);
-static void refresh_user_types(const bec::NodeId &parent, int orow, WBModelSidebarController *self);
-
 - (void)setupWithWBContextUI:(wb::WBContextUI*)wbui
 {
   _wbui= wbui;
@@ -53,8 +52,6 @@ static void refresh_user_types(const bec::NodeId &parent, int orow, WBModelSideb
   */
   [catalogOutline setDoubleAction:@selector(activateCatalogItem:)];
   [catalogOutline setTarget:self];
-  [historyTable setDoubleAction:@selector(activateHistoryItem:)];
-  [historyTable setTarget:self];
   
   // set backend model for catalog DS
   [catalogDS setHidesRootNode:YES];
@@ -63,19 +60,15 @@ static void refresh_user_types(const bec::NodeId &parent, int orow, WBModelSideb
   [catalogDS setTreeModel: _wbui->get_catalog_tree()];
   
   // set backend for usertype ds
-  if (userTypeDS)
-  {
-    [userTypeDS setListModel: _wbui->get_usertypes_tree()];
-    _userTypesRefresh = _wbui->get_usertypes_tree()->tree_changed_signal()->connect(boost::bind(refresh_user_types, _1, _2, self));
-  }
+  _udtlist = _wbui->get_wb()->get_model_context()->create_user_type_list();
+  NSView *udtview = nsviewForView(_udtlist);
+  [userTypesTab setView: udtview];
+
+  // set backend for history DS
+  _history = _wbui->get_wb()->get_model_context()->create_history_tree();
+  NSView *hview = nsviewForView(_history);
+  [historyTab setView: hview];
 
-  // set backend model for history DS
-  if (historyDS)
-  {
-    [historyDS setListModel:_wbui->get_history_tree()];
-    _historyRefresh = _wbui->get_history_tree()->tree_changed_signal()->connect(boost::bind(refresh_history, _1, _2, self));
-  }
-  
   [self refresh];  
 }
 
@@ -85,34 +78,22 @@ static void refresh_user_types(const bec::NodeId &parent, int orow, WBModelSideb
   if (sidebar)
   {
     catalogDS = sidebar->catalogDS;
-    historyDS = sidebar->historyDS;
-    userTypeDS = sidebar->userTypeDS;
   }
   else
   {
     catalogDS = nil;
-    historyDS = nil;
-    userTypeDS = nil;
   }
   
   [catalogOutline setDataSource: catalogDS];
   [catalogOutline setDelegate: self];
-  
-  [historyTable setDataSource: historyDS];
-  [historyTable setDelegate: historyDS];
-  
-  [userTypeTable setDataSource: userTypeDS];
-  [userTypeTable setDelegate: userTypeDS];
 }
 
 
 - (void)dealloc
-{ 
-  _wbui= 0;
+{
+  delete _udtlist;
+  delete _history;
   
-  _historyRefresh.disconnect();
-  _userTypesRefresh.disconnect();
-  [[NSNotificationCenter defaultCenter] removeObserver: self];
   [super dealloc];
 }
 
@@ -142,45 +123,6 @@ static void refresh_user_types(const bec::NodeId &parent, int orow, WBModelSideb
   
   if ([command compare: @"refreshCatalog"] == NSOrderedSame)
     [self refreshCatalogTree];
-  else
-    if ([command compare: @"copyHistory"] == NSOrderedSame)
-      [self copyHistoryToPasteboard];
-}
-
-//--------------------------------------------------------------------------------------------------
-
-- (void) copyHistoryToPasteboard
-{
-  NSString* text = @"";
-  
-  bec::ListModel* model = [historyDS listModel];
-  std::vector<bec::NodeId> nodes = [historyTable selectedNodeIds];
-  if (nodes.size() > 0)
-  {
-    // Copy only selected items if there are any.
-    for (int i = 0; i < (int)nodes.size(); i++)
-    {
-      std::string label;
-      model->get_field(nodes[i], 0, label);
-      text = [NSString stringWithFormat: @"%@%@\n", text, [NSString stringWithUTF8String: label.c_str()]];
-    }
-  }
-  else
-  {
-    // Nothing selected, copy everything.
-    for (int i = 0; i < model->count(); i++)
-    {
-      bec::NodeId node = model->get_node(i);
-      
-      std::string label;
-      model->get_field(node, 0, label);
-      text = [NSString stringWithFormat: @"%@%@\n", text, [NSString stringWithUTF8String: label.c_str()]];
-    }
-  }    
-  
-  NSPasteboard* pasteboard= [NSPasteboard generalPasteboard];
-  [pasteboard declareTypes: [NSArray arrayWithObject: NSStringPboardType] owner: nil];
-  [pasteboard setString: text forType: NSStringPboardType];
 }
 
 //--------------------------------------------------------------------------------------------------
@@ -195,27 +137,8 @@ static void refresh_user_types(const bec::NodeId &parent, int orow, WBModelSideb
 - (void)refresh
 {
   [self refreshCatalogTree];
-  [self refreshUserTypeList];
-  [self refreshHistory];
 }
 
-- (void)refreshUserTypeList
-{
-  if (_wbui)
-  {
-    NSPoint pos = [[[userTypeTable enclosingScrollView] contentView] documentVisibleRect].origin;
-    
-    if ([userTypeDS listModel])
-      [userTypeDS listModel]->refresh();
-  
-    [userTypeTable reloadData];
-    
-    [[[userTypeTable enclosingScrollView] contentView] scrollToPoint: pos];
-    [[userTypeTable enclosingScrollView] reflectScrolledClipView: [[userTypeTable enclosingScrollView] contentView]];
-  }
-}
-
-
 - (void)refreshCatalogTree
 {
   if (_wbui)
@@ -335,33 +258,12 @@ static void refresh_user_types(const bec::NodeId &parent, int orow, WBModelSideb
 }
 
 
-- (void)refreshHistory
-{
-  if (_wbui)
-  {
-    NSPoint pos = [[[historyTable enclosingScrollView] contentView] documentVisibleRect].origin;
-    
-    _wbui->get_history_tree()->refresh();
-    [historyTable reloadData];
-    
-    [[[historyTable enclosingScrollView] contentView] scrollToPoint: pos];
-    [[historyTable enclosingScrollView] reflectScrolledClipView: [[historyTable enclosingScrollView] contentView]];
-  }
-}
-
-
 - (IBAction)activateCatalogItem:(id)sender
 {
   _wbui->get_catalog_tree()->activate_node([catalogDS nodeIdForItem:[catalogOutline itemAtRow: [catalogOutline clickedRow]]]);
 }
 
 
-- (IBAction)activateHistoryItem:(id)sender
-{
-  if ([historyTable clickedRow] >= 0)
-    _wbui->get_history_tree()->activate_node(bec::NodeId([historyTable clickedRow]));
-}
-
 //--------------------------------------------------------------------------------------------------
 
 - (NSOutlineView*) catalogOutline
@@ -375,42 +277,4 @@ static void refresh_user_types(const bec::NodeId &parent, int orow, WBModelSideb
 {
   return catalogDS;
 }
-
-//--------------------------------------------------------------------------------------------------
-
-- (NSTableView*) historyTable
-{
-  return historyTable;
-}
-
-//--------------------------------------------------------------------------------------------------
-
-- (GRTListDataSource*) historyDS
-{
-  return historyDS;
-}
-
-//--------------------------------------------------------------------------------------------------
-
-- (GRTListDataSource*) userTypeDS
-{
-  return userTypeDS;
-}
-
-//--------------------------------------------------------------------------------------------------
-
-static void refresh_history(const bec::NodeId &parent, int orow, WBModelSidebarController *self)
-{
-  [self performSelectorOnMainThread:@selector(refreshHistory)
-                         withObject:nil
-                      waitUntilDone:NO];
-}
-
-static void refresh_user_types(const bec::NodeId &parent, int orow, WBModelSidebarController *self)
-{
-  [self performSelectorOnMainThread:@selector(refreshUserTypeList)
-                         withObject:nil
-                      waitUntilDone:NO];
-}
-
 @end
