@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2009, 2011, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2009, 2012, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -17,6 +17,9 @@
  * 02110-1301  USA
  */
 
+#include "base/geometry.h"
+#include "base/string_utilities.h"
+#import "base/log.h"
 
 #import "WBSQLQueryPanel.h"
 
@@ -25,10 +28,11 @@
 #import "WBQueryTab.h"
 #import "MResultsetViewer.h"
 
+#include "mforms/code_editor.h"
+
 #include "workbench/wb_context_ui.h"
 
 #import "WBSQLQueryUI.h"
-#import "base/log.h"
 
 DEFAULT_LOG_DOMAIN(DOMAIN_WQE_NATIVE)
 
@@ -48,6 +52,22 @@ static WBSQLQueryPanel *getQueryPanel(wb::WBContextUI *wbui)
 }
 
 
+static void call_jump_to_placeholder(wb::WBContextUI *wbui)
+{
+  Sql_editor::Ref ed = [getQueryPanel(wbui) activeEditor];
+  if (ed)
+    ed->get_editor_control()->jump_to_next_placeholder();
+}
+
+static bool validate_jump_to_placeholder(wb::WBContextUI *wbui)
+{
+  id panel = getQueryPanel(wbui);
+  if (panel)
+    return [panel activeEditor] != nil;
+  return false;
+}
+
+
 static WBBasePanel *createQueryPanel(WBMainWindow *mainwin, boost::shared_ptr<bec::UIForm> form)
 {
   SqlEditorForm::Ref editor= boost::dynamic_pointer_cast<SqlEditorForm>(form);
@@ -62,8 +82,8 @@ static WBBasePanel *createQueryPanel(WBMainWindow *mainwin, boost::shared_ptr<be
 void setupSQLQueryUI(WBMainController *main, WBMainWindow *mainwin, wb::WBContextUI *wbui)
 {  
   log_debug("Setting up UI\n");
-//  wbui->get_command_ui()->add_builtin_command("query.jump_to_placeholder", boost::bind(call_jump_to_placeholder, wbui), 
-//                                              boost::bind(validate_jump_to_placeholder, wbui));
+  wbui->get_command_ui()->add_builtin_command("query.jump_to_placeholder", boost::bind(call_jump_to_placeholder, wbui), 
+                                              boost::bind(validate_jump_to_placeholder, wbui));
   
   // other commands in wb_context_sqlide.cpp
 
