@@ -76,20 +76,20 @@ namespace MySQL.Grt
 
       foreach (ColumnContent column in columns)
       {
+        NodeTextBox node = column.control as NodeTextBox;
+        node.ValueNeeded -= ValueNeeded;
         if (column.editable)
         {
-          NodeTextBox node = column.control as NodeTextBox;
           if (node != null)
           {
-            // remove virtual value events
             node.ValuePushed -= ValuePushed;
-            node.ValueNeeded -= ValueNeeded;
 
             if (node is AdvNodeTextBox)
               ((AdvNodeTextBox)node).EditorInitialize -= EditorInitialize;
           }
         }
       }
+      columns = null;
     }
 
     /// <summary>
