@@ -230,6 +230,13 @@ namespace MySQL.Controls
       using (SolidBrush brush = new SolidBrush(color))
         e.Graphics.DrawString(e.Text, e.TextFont, brush, e.TextRectangle);
     }
+
+    protected override void OnRenderButtonBackground(ToolStripItemRenderEventArgs e)
+    {
+      if (e.Item.BackgroundImage != null)
+        e.Graphics.DrawImageUnscaledAndClipped(e.Item.BackgroundImage,
+          new Rectangle(0, 0, e.Item.Width, e.Item.Height));
+    }
   }
 
   //------------------------------------------------------------------------------------------------
