@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2009, 2011, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2009, 2012, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -32,9 +32,8 @@ namespace MySQL.Grt.Db
 {
   public partial class RecordsetView : Form
   {
-    private Recordset model;
+    private RecordsetWrapper model;
     private GridView gridView;
-    //private DataExportForm dataExportForm;
     private ColumnFilterDialog columnFilterDialog = new ColumnFilterDialog();
     private int contextColumnIndex;
     private int contextRowIndex;
@@ -46,13 +45,13 @@ namespace MySQL.Grt.Db
       InitializeComponent();
 
       dataSearchTimer = new Timer();
-      dataSearchTimer.Interval = 2000;
+      dataSearchTimer.Interval = 1000;
       dataSearchTimer.Tick += new EventHandler(OnDataSearchApply);
 
       mainToolStrip.Renderer = new FlatSubToolStripRenderer();
     }
 
-    public void Embed(Control parent, Recordset recordset)
+    public void Embed(Control parent, RecordsetWrapper recordset)
     {
       recordsetPanel.Parent = parent;
 
@@ -63,6 +62,7 @@ namespace MySQL.Grt.Db
       gridView.StandardTab = false; // Let Tab move the cursor to the next cell instead next control in parent tab order.
 
       gridView.KeyDown += gridView_KeyDown;
+      gridView.MouseDown += gridView_MouseDown;
       gridView.ColumnHeaderMouseClick += gridView_ColumnHeaderMouseClick;
       gridView.CellContextMenuStripNeeded += gridView_CellContextMenuStripNeeded;
       gridView.CellStateChanged += gridView_CellStateChanged;
@@ -83,12 +83,8 @@ namespace MySQL.Grt.Db
         foreach (ToolStripItem item in mainToolStrip.Items)
           existingToolStripItems.Add(item);
 
-        WorkbenchToolbarManager.get_instance().UpdateToolbar(mainToolStrip, items, TriggerAction);
+        WorkbenchToolbarManager.Instance.UpdateToolbar(mainToolStrip, items, TriggerAction);
         
-        // XXX hack. this should be changed so that the whole toolbar is generated automatically
-        if (items[items.Count - 1].get_name() == "recall_query")
-          mainToolStrip.Items[mainToolStrip.Items.Count - 1].Alignment = ToolStripItemAlignment.Right;
-
         foreach (ToolStripItem item in existingToolStripItems)
           mainToolStrip.Items.Add(item);
       }
@@ -96,41 +92,45 @@ namespace MySQL.Grt.Db
       Model = recordset;
     }
 
+    public bool Dirty
+    {
+      get { return model.has_pending_changes(); }
+    }
+
     public GridView GridView
     {
       get { return gridView; }
     }
 
-    public Recordset Model
+    public RecordsetWrapper Model
     {
       set
       {
         gridView.Model = value;
         model = value;
         model.refresh_ui_cb(ProcessModelChange);
+        model.add_tree_refresh_handler(ProcessTreeRefresh);
         model.refresh_ui_status_bar_cb(UpdateStatusBar);
         model.task.msg_cb(ProcessTaskMsg);
 
         ActionList actionList = model.action_list;
-        actionList.register_action("record_first", OnRecordFirst);
-        actionList.register_action("record_back", OnRecordBack);
-        actionList.register_action("record_next", OnRecordNext);
-        actionList.register_action("record_last", OnRecordLast);
-        //actionList.register_action("record_fetch_all", OnRecordFetchAll);
-        actionList.register_action("record_wrap_vertical", OnRecordWrapVertical);
-        actionList.register_action("record_sort_asc", OnRecordSortAsc);
-        actionList.register_action("record_sort_desc", OnRecordSortDesc);
-        actionList.register_action("record_edit", OnRecordEdit);
-        actionList.register_action("record_add", OnRecordAdd);
-        actionList.register_action("record_del", OnRecordDel);
-        actionList.register_action("record_save", OnRecordSave);
-        actionList.register_action("record_discard", OnRecordDiscard);
-        //actionList.register_action("record_refresh", OnRecordRefresh);
+        actionList.register_action("record_first", RecordNavigateFirst);
+        actionList.register_action("record_back", RecordNavigateBack);
+        actionList.register_action("record_next", RecordNavigateNext);
+        actionList.register_action("record_last", RecordNavigateLast);
+        actionList.register_action("record_wrap_vertical", ToggleGridWrapMode);
+        actionList.register_action("record_sort_asc", SortAscending);
+        actionList.register_action("record_sort_desc", SortDescending);
+        actionList.register_action("record_edit", EditSelectedRecord);
+        actionList.register_action("record_add", AddNewRecord);
+        actionList.register_action("record_del", DeleteCurrentRecord);
+        actionList.register_action("record_save", SaveChanges);
+        actionList.register_action("record_discard", DiscardChanges);
 
         // init popup menu
         {
           actionList.register_rows_col_action("set_to_null", OnSelectedFieldsNullify);
-          actionList.register_rows_col_action("delete_row", OnSelectedRowsDelete);
+          actionList.register_rows_col_action("delete_row", DeleteSelectedRecords);
 
           SqlIdeMenuManager.MenuContext popupMenuContext = new SqlIdeMenuManager.MenuContext();
           popupMenuContext.ActionList = model.action_list;
@@ -144,6 +144,7 @@ namespace MySQL.Grt.Db
       get { return model; }
     }
 
+    // TODO: seems local message are no longer needed. So this code and the split container can be removed.
     private int ProcessTaskMsg(int msgType, String message, String detail)
     {
       messagesTB.Text = message;
@@ -166,25 +167,36 @@ namespace MySQL.Grt.Db
       return 0;
     }
 
-    void UpdateToolBar()
-    {
-      dataSearchExprTB.Text = model.data_search_string();
-      dataSearchTimer.Stop();
-    }
-
     private int UpdateStatusBar()
     {
-      dataStatusLabel.Text = model.status_text();
-      gridView.Refresh();
+      //gridView.Refresh();
       return 0;
     }
 
+    private bool pendingRefresh = false;
+    private void ProcessTreeRefresh(NodeId node, int ocount)
+    {
+      if (!pendingRefresh)
+      {
+        Application.Idle += new EventHandler(OnIdle);
+        pendingRefresh = true;
+      }
+    }
+
+    private void OnIdle(Object sender, EventArgs e)
+    {
+      gridView.Refresh();
+      gridView.ProcessModelRowsChange();
+      pendingRefresh = false;
+      Application.Idle -= OnIdle;
+    }
+    
     public int ProcessModelChange()
     {
+      dataSearchTimer.Stop();
       gridView.ProcessModelChange();
 
       UpdateStatusBar();
-      UpdateToolBar();
 
       setNullMenuItem.Enabled = !gridView.ReadOnly;
       deleteRowsMenuItem.Enabled = !gridView.ReadOnly;
@@ -192,42 +204,22 @@ namespace MySQL.Grt.Db
       return 0;
     }
 
-    private bool TriggerAction(String name)
-    {
-      return model.action_list.trigger_action(name);
-    }
+    private string lastSearchString = "";
 
-    public bool PinButtonVisible
+    private bool TriggerAction(String name, object data)
     {
-      set
+      if (name == "filter")
       {
-        pinButton.Visible = value;
+        lastSearchString = data as string;
+        dataSearchTimer.Stop();
+        dataSearchTimer.Start();
+        return true;
       }
+      else
+        return model.action_list.trigger_action(name);
     }
 
-    private void pinButton_Click(object sender, EventArgs e)
-    {
-      model.pinned(!model.pinned());
-      pinButton.Checked = model.pinned();
-      pinButton.Image = pinButton.Checked ? Properties.Resources.tiny_pinned : Properties.Resources.tiny_pin;
-    }
-
-    private void OnRecordRefresh()
-    {
-      model.refresh();
-    }
-
-    private void OnRecordDiscard()
-    {
-      model.rollback();
-    }
-
-    private void OnRecordSave()
-    {
-      // Apply any pending changes in the grid before writing them to model.
-      gridView.EndEdit();
-      model.apply_changes();
-    }
+    #region Message handling
 
     private void setNullMenuItem_Click(object sender, EventArgs e)
     {
@@ -263,65 +255,11 @@ namespace MySQL.Grt.Db
       }
     }
 
-    private void OnRecordWrapVertical()
-    {
-      gridView.WrapMode = !gridView.WrapMode;
-    }
-
     private void closeButton_Click(object sender, EventArgs e)
     {
-      model.close(); // after this call the object is disposed
-    }
-
-    private void OnRecordFirst()
-    {
-      gridView.SetRowSelected(0);
-    }
-
-    private void OnRecordBack()
-    {
-      if (contextRowIndex == -1)
-        return;
-      int rowIndex = contextRowIndex - 1;
-      if (rowIndex >= 0)
-        gridView.SetRowSelected(rowIndex);
-    }
-
-    private void OnRecordNext()
-    {
-      if (contextRowIndex == -1)
-        return;
-      int rowIndex = contextRowIndex + 1;
-      if (rowIndex < gridView.RowCount)
-        gridView.SetRowSelected(rowIndex);
-    }
-
-    private void OnRecordLast()
-    {
-      gridView.SetRowSelected(gridView.RowCount - 1);
-    }
-
-    private void OnRecordEdit()
-    {
-      if (gridView.SelectedCells.Count > 0)
-        gridView.BeginEdit(false);
-    }
-
-    private void OnRecordAdd()
-    {
-      OnRecordLast();
-      if (gridView.Columns.Count > 0)
-        gridView.BeginEdit(false);
-    }
-
-    private void OnRecordDel()
-    {
-      deleteRowsMenuItem_Click(null, null);
-    }
-
-    private void OnSelectedRowsDelete(List<int> rows, int column)
-    {
-      deleteRowsMenuItem_Click(null, null);
+      if (model.can_close())
+        model.close(); // This will remove the record set from the back with a notification
+                       // to remove the UI (handled in SqlIdeForm.cs).
     }
 
     private void deleteRowsMenuItem_Click(object sender, EventArgs e)
@@ -368,6 +306,24 @@ namespace MySQL.Grt.Db
       }
     }
 
+    private void gridView_MouseDown(object sender, MouseEventArgs e)
+    {
+      if (e.Button == MouseButtons.Right)
+      {
+        DataGridView.HitTestInfo info = gridView.HitTest(e.X, e.Y);
+        if (info.ColumnIndex < 0 || info.RowIndex < 0)
+          return;
+
+        DataGridViewCell cell = gridView[info.ColumnIndex, info.RowIndex];
+        if (!cell.Selected)
+        {
+          if (Control.ModifierKeys == Keys.None)
+            gridView.ClearSelection();
+          cell.Selected = true;
+        }
+      }
+    }
+
     private void gridView_ColumnHeaderMouseClick(object sender, DataGridViewCellMouseEventArgs e)
     {
       if (MouseButtons.Left == e.Button)
@@ -402,22 +358,6 @@ namespace MySQL.Grt.Db
       model.reset_column_filters();
     }
 
-    private void dataSearchExprTB_TextChanged(object sender, EventArgs e)
-    {
-      dataSearchTimer.Stop();
-      dataSearchTimer.Start();
-    }
-
-    private void dataSearchExprTB_KeyDown(object sender, KeyEventArgs e)
-    {
-      switch (e.KeyCode)
-      {
-        case Keys.Return:
-          OnDataSearchApply(null, null);
-          break;
-      }
-    }
-
     private void SortByColumn(int columnIndex, int direction, bool retaining)
     {
       SortOrder sortOrder;
@@ -431,29 +371,13 @@ namespace MySQL.Grt.Db
       model.sort_by(columnIndex, direction, retaining);
     }
 
-    private void OnRecordSortAsc()
-    {
-      if (contextColumnIndex == -1)
-        return;
-      int direction = (gridView.Columns[contextColumnIndex].HeaderCell.SortGlyphDirection == SortOrder.Ascending ? 0 : 1);
-      SortByColumn(contextColumnIndex, direction, true);
-    }
-
-    private void OnRecordSortDesc()
-    {
-      if (contextColumnIndex == -1)
-        return;
-      int direction = (gridView.Columns[contextColumnIndex].HeaderCell.SortGlyphDirection == SortOrder.Descending ? 0 : -1);
-      SortByColumn(contextColumnIndex, direction, true);
-    }
-
     private void OnDataSearchApply(object sender, EventArgs e)
     {
       dataSearchTimer.Stop();
-      if (dataSearchExprTB.Text.Length == 0)
+      if (lastSearchString.Length == 0)
         model.reset_data_search_string();
       else
-        model.set_data_search_string(dataSearchExprTB.Text);
+        model.set_data_search_string(lastSearchString);
     }
 
     void gridView_CellStateChanged(object sender, DataGridViewCellStateChangedEventArgs e)
@@ -467,7 +391,7 @@ namespace MySQL.Grt.Db
         }
         else if (gridView.SelectedCells.Count > 0)
         {
-          DataGridViewCell cell = gridView.SelectedCells[gridView.SelectedCells.Count-1];
+          DataGridViewCell cell = gridView.SelectedCells[gridView.SelectedCells.Count - 1];
           contextColumnIndex = cell.ColumnIndex;
           contextRowIndex = cell.RowIndex;
         }
@@ -517,9 +441,101 @@ namespace MySQL.Grt.Db
       e.Handled = true;
     }
 
-    private void searchButton_Click(object sender, EventArgs e)
+    #endregion
+
+    #region record set manipulations
+
+    public void RefreshRecords()
     {
-      OnDataSearchApply(null, null);
+      model.refresh();
     }
+
+    public void DiscardChanges()
+    {
+      gridView.CancelEdit();
+      model.rollback();
+    }
+
+    public void SaveChanges()
+    {
+      // Apply any pending changes in the grid before writing them to model.
+      gridView.EndEdit();
+      model.apply_changes();
+    }
+
+    public void ToggleGridWrapMode()
+    {
+      gridView.WrapMode = !gridView.WrapMode;
+    }
+
+    public void RecordNavigateFirst()
+    {
+      gridView.SetRowSelected(0);
+    }
+
+    public void RecordNavigateBack()
+    {
+      if (contextRowIndex == -1)
+        return;
+      int rowIndex = contextRowIndex - 1;
+      if (rowIndex >= 0)
+        gridView.SetRowSelected(rowIndex);
+    }
+
+    public void RecordNavigateNext()
+    {
+      if (contextRowIndex == -1)
+        return;
+      int rowIndex = contextRowIndex + 1;
+      if (rowIndex < gridView.RowCount)
+        gridView.SetRowSelected(rowIndex);
+    }
+
+    public void RecordNavigateLast()
+    {
+      gridView.SetRowSelected(gridView.RowCount - 1);
+    }
+
+    public void EditSelectedRecord()
+    {
+      if (gridView.SelectedCells.Count > 0)
+        gridView.BeginEdit(false);
+    }
+
+    public void AddNewRecord()
+    {
+      RecordNavigateLast();
+      if (gridView.Columns.Count > 0)
+        gridView.BeginEdit(false);
+    }
+
+    public void DeleteCurrentRecord()
+    {
+      deleteRowsMenuItem_Click(null, null);
+    }
+
+    public void DeleteSelectedRecords(List<int> rows, int column)
+    {
+      deleteRowsMenuItem_Click(null, null);
+    }
+
+    public void SortAscending()
+    {
+      if (contextColumnIndex == -1)
+        return;
+      int direction = (gridView.Columns[contextColumnIndex].HeaderCell.SortGlyphDirection == SortOrder.Ascending ? 0 : 1);
+      SortByColumn(contextColumnIndex, direction, true);
+    }
+
+    public void SortDescending()
+    {
+      if (contextColumnIndex == -1)
+        return;
+      int direction = (gridView.Columns[contextColumnIndex].HeaderCell.SortGlyphDirection == SortOrder.Descending ? 0 : -1);
+      SortByColumn(contextColumnIndex, direction, true);
+    }
+
+    #endregion
+
   }
 }
