@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2009, 2011, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2009, 2012, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -30,8 +30,7 @@
 #include "common.h"
 #endif
 
-namespace MySQL {
-namespace Geometry {
+namespace base {
 
 #ifndef SWIG
 
@@ -145,12 +144,28 @@ namespace Geometry {
     int right;
     int bottom;
 
+    Padding();
     Padding(int padding);
     Padding(int left, int top, int right, int bottom);
 
+    int horizontal();
+    int vertical();
+    
   } Padding;
 
-}
-}
+  /** A struct describing a range in a container. */
+  struct BASELIBRARY_PUBLIC_FUNC Range
+  {
+    int position;
+    int size;
+
+    Range();
+    Range(int position, int size);
+
+    int end();
+    bool contains_point(int point);
+  };
+
+} // namespace base
 
 #endif /* _GEOMETRY_H_ */
