@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2011, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2011, 2012, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -21,7 +21,11 @@
 
 #include "mforms/hypertext.h"
 
-@interface MFHyperTextView : NSScrollView {
+@interface MFHyperTextView : NSScrollView
+#ifdef MAC_OS_X_VERSION_10_6
+    <NSTextViewDelegate>
+#endif
+{
   mforms::HyperText *mOwner;
   NSTextView *mTextView;
   NSInteger mTag;
