@@ -320,6 +320,10 @@ public:
   { 
     if (is_valid())
     {
+      NSString *tag = [_self objectForKey: @"tag"];
+      if (tag)
+        [_self->mTree setNode: nil forTag: [tag UTF8String]];
+
       if ([_self parent])
         [_self removeFromParent];
       else
@@ -331,7 +335,15 @@ public:
   {
     //XXX
     if (is_valid())
+    {
+      for (id ch in [_self children])
+      {
+        NSString *tag = [_self objectForKey: @"tag"];
+        if (tag)
+          [_self->mTree setNode: nil forTag: [tag UTF8String]];
+      }
       [[_self children] removeAllObjects];
+    }
   }
   
   virtual mforms::TreeNodeRef get_child(int index) const
@@ -358,13 +370,15 @@ public:
   virtual void expand()
   {
     mforms::TreeNodeRef parent(get_parent());
-    
-    NSLog(@"expanding node");
+
     if (parent)
       parent->expand();
-    
-    
-    [[[_self treeNodeView] outlineView] expandItem: _self];
+
+    [[[_self treeNodeView] outlineView] performSelector: @selector(expandItem:)
+                                             withObject: _self
+                                             afterDelay: 0.0];
+
+//    [[[_self treeNodeView] outlineView] expandItem: _self];
   }
   
   virtual void collapse()
@@ -379,6 +393,11 @@ public:
   
   virtual void set_tag(const std::string &tag)
   {
+    NSString *tstr = [_self objectForKey: @"tag"];
+
+    if (tstr)
+      [_self->mTree setNode: nil forTag: [tstr UTF8String]];
+    [_self->mTree setNode: _self forTag: tag];
     [_self setObject: [NSString stringWithCPPString: tag]
               forKey: @"tag"];
   }
@@ -587,18 +606,9 @@ inline TreeNodeImpl *from_ref(mforms::TreeNodeRef node)
   NSMutableArray *children = [mParent children];
   if (children)
   {
-    int i = 0;
-    for (id obj in children)
-    {
-      if (obj == self)
-      {
-        mParent = nil;
-        [[self retain] autorelease];
-        [children removeObjectAtIndex: i];
-        break;
-      }
-      i++;
-    }
+    [[self retain] autorelease];
+    [children removeObject: self];
+    mParent = nil;
    
     if (![[self treeNodeView] frozen])
       [[[self treeNodeView] outlineView] reloadData];
@@ -707,8 +717,15 @@ static NSImage *descendingSortIndicator=nil;
 }
 
 
+- (void)enableIndexing
+{
+  mTagIndexEnabled = YES;
+}
+
+
 - (void) dealloc
 {
+  mTagMap.clear();
   [mAttributedFonts release];
   [mColumnKeys release];
   [mIconCache release];
@@ -1150,6 +1167,19 @@ sortDescriptorsDidChange:(NSArray *)oldDescriptors
 }
 
 
+
+- (void)setNode: (MFTreeNodeImpl*)node forTag: (const std::string&)tag
+{
+  if (!tag.empty() && mTagIndexEnabled)
+  {
+    if (!node)
+      mTagMap.erase(tag);
+    else
+      mTagMap[tag] = node; // reference only
+  }
+}
+
+
 static bool treeview_create(mforms::TreeNodeView *self, mforms::TreeOptions options)
 {
   MFTreeNodeViewImpl *tree= [[[MFTreeNodeViewImpl alloc] initWithObject: self] autorelease];
@@ -1185,6 +1215,8 @@ static bool treeview_create(mforms::TreeNodeView *self, mforms::TreeOptions opti
     [tree->mOutline setFocusRingType: NSFocusRingTypeNone];
     [tree setAutohidesScrollers: YES];
   }
+  if (options & mforms::TreeIndexOnTag)
+    [tree enableIndexing];
   [tree->mOutline setGridStyleMask: mask];
 
   if (options & mforms::TreeAltRowColors)
@@ -1463,6 +1495,20 @@ static mforms::TreeNodeRef find_node_at_row(mforms::TreeNodeRef node, int &row_c
   return res;
 }
 
+
+static mforms::TreeNodeRef treeview_node_with_tag(mforms::TreeNodeView *self, const std::string &tag)
+{
+  MFTreeNodeViewImpl *tree= self->get_data();
+  if (tree->mTagIndexEnabled)
+  {
+    std::map<std::string, MFTreeNodeImpl*>::iterator iter;
+    if ((iter = tree->mTagMap.find(tag)) != tree->mTagMap.end())
+      return [iter->second nodeRef];
+  }
+  return mforms::TreeNodeRef();
+}
+
+
 static mforms::TreeNodeRef treeview_node_at_row(mforms::TreeNodeView *self, int row)
 {
   MFTreeNodeViewImpl *tree= self->get_data();
@@ -1523,7 +1569,7 @@ void cf_treenodeview_init()
   
   f->_treenodeview_impl.row_for_node = &treeview_row_for_node;
   f->_treenodeview_impl.node_at_row = &treeview_node_at_row;
-
+  f->_treenodeview_impl.node_with_tag = &treeview_node_with_tag;
 }
 
 
