@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2009, 2010, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2009, 2012, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -16,6 +16,8 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
  * 02110-1301  USA
  */
+#include "../lf_mforms.h"
+
 #include "../lf_wizard.h"
 #include "../lf_form.h"
 #include "text_list_columns_model.h"
@@ -112,6 +114,7 @@ WizardImpl::WizardImpl(::mforms::Wizard *wiz, ::mforms::Form* owner)
   _step_table.set_row_spacings(8);
 
   _step_background.add(_step_table);
+  if (!force_sys_colors)
   {
     Gdk::Color c("#ffffff");
     _dlg.get_colormap()->alloc_color(c);
@@ -178,9 +181,11 @@ void WizardImpl::run_modal(::mforms::Wizard *self)
 {
   WizardImpl* wiz = self->get_data<WizardImpl>();
 
+  wiz->_dlg.set_modal(true);
   wiz->_dlg.show();
   wiz->_dlg.set_transient_for(*get_mainwindow());
   Gtk::Main::run();
+  wiz->_dlg.set_modal(false);
 }
 
 //------------------------------------------------------------------------------
