@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2008, 2010, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2008, 2012, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -16,16 +16,10 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
  * 02110-1301  USA
  */
+
 #include "stdafx.h"
 
-#include <mforms/simpleform.h>
-#include <mforms/mforms.h>
-
-#include <stdlib.h>
-#include <string.h>
-
-#include <sstream>
-#include <stdexcept>
+#include "mforms/mforms.h"
 
 #define MIN_VIEW_WIDTH 200
 #define FORM_MARGIN  12
@@ -34,6 +28,7 @@ using namespace std;
 using namespace mforms;
 
 SimpleForm::SimpleForm(const std::string &title, const std::string &ok_caption)
+: Form(NULL)
 {
   _caption_width= 0;
   _view_width= 0;
@@ -45,10 +40,7 @@ SimpleForm::SimpleForm(const std::string &title, const std::string &ok_caption)
 
   _ok_caption= ok_caption;
 
-  _form= new Form(NULL, mforms::FormSingleFrame);
-  _form->set_title(title);
-  
-  //_form->set_size(640,480); //XXX hack delme
+  set_title(title);
   
   _content= new Table();
   _content->set_padding(12);
@@ -68,7 +60,6 @@ SimpleForm::~SimpleForm()
   delete _ok_button;
   delete _cancel_button;
   delete _button_box;
-  delete _form;
 }
 
 
@@ -224,8 +215,8 @@ void SimpleForm::add_text_entry(const std::string &name, const std::string &capt
   if (!caption.empty())
   {
     l= new Label(caption);
-    l->set_text_align(BottomRight);
-    _content->add(l, 0, 1, _rows.size(), _rows.size()+1, 0);
+    l->set_text_align(MiddleRight);
+    _content->add(l, 0, 1, _rows.size(), _rows.size()+1, HFillFlag);
 
     int w= l->get_preferred_width();
     _caption_width= max(w, _caption_width);
@@ -318,7 +309,7 @@ void SimpleForm::add_select(const std::string &name, const std::string &caption,
   if (!caption.empty())
   {
     l= new Label(caption);
-    l->set_text_align(BottomRight);
+    l->set_text_align(MiddleRight);
     _content->add(l, 0, 1, _rows.size(), _rows.size()+1, 0);
 
     int w= l->get_preferred_width();
@@ -346,12 +337,14 @@ bool SimpleForm::show()
 {
   if (!_button_box)
   {
-    _form->set_content(_content);
+    set_content(_content);
+    center();
 
     _button_box= new Box(true);
     _button_box->set_spacing(8);
 
-    _content->set_row_count(_rows.size()+1);
+    _content->set_row_count(_rows.size()+2);
+    _content->add(manage(new Label("")), 0, 2, _rows.size()-1, _rows.size(), HFillFlag);
     _content->add(_button_box, 0, 2, _rows.size(), _rows.size()+1, HFillFlag);
 
     _ok_button= new Button();
@@ -361,11 +354,10 @@ bool SimpleForm::show()
     _cancel_button= new Button();
     _cancel_button->set_text("Cancel");
     _button_box->add_end(_cancel_button, false, true);
-
   }
 
 
-  return _form->run_modal(_ok_button, _cancel_button);
+  return run_modal(_ok_button, _cancel_button);
 }
 
 
