@@ -23,6 +23,15 @@
 
 #include "stdafx.h"
 
+#include "mforms/mforms.h"
+#include "wf_view.h"
+#include "wf_box.h"
+#include "wf_appview.h"
+#include "wf_menubar.h"
+#include "wf_toolbar.h"
+
+#include "ConvUtils.h"
+
 using namespace System::Drawing::Drawing2D;
 
 using namespace MySQL::Forms;
@@ -116,6 +125,13 @@ AppViewImpl::AppViewImpl(::mforms::AppView* app)
 
 //--------------------------------------------------------------------------------------------------
 
+AppViewImpl::~AppViewImpl()
+{
+  delete _host;
+}
+
+//--------------------------------------------------------------------------------------------------
+
 void AppViewImpl::setup()
 {
   // In order to ease maintenance we create a special document host for our content.
