@@ -19,6 +19,12 @@
 
 #include "stdafx.h"
 
+#include "mforms/mforms.h"
+#include "wf_view.h"
+#include "wf_menubar.h"
+
+#include "ConvUtils.h"
+
 using namespace System::Windows::Forms;
 using namespace System::Drawing;
 
