@@ -23,6 +23,13 @@
 
 #include "stdafx.h"
 
+#include "mforms/mforms.h"
+#include "wf_view.h"
+#include "wf_textbox.h"
+
+#include "base/log.h"
+#include "ConvUtils.h"
+
 using namespace MySQL::Forms;
 
 using namespace System::Windows::Forms;
