@@ -17,12 +17,20 @@
  * 02110-1301  USA
  */
 
-#include "stdafx.h"
-
 /**
  * Implementation of the mforms wizard form.
  */
 
+#include "stdafx.h"
+
+#include "mforms/mforms.h"
+#include "wf_view.h"
+#include "wf_form.h"
+#include "wf_wizard.h"
+
+#include "base/log.h"
+#include "ConvUtils.h"
+
 using namespace System::IO;
 using namespace Drawing::Drawing2D;
 
@@ -55,7 +63,7 @@ bool WizardImpl::create(mforms::Wizard* self, mforms::Form* owner)
 
 //--------------------------------------------------------------------------------------------------
 
-void WizardImpl::set_title(::mforms::Wizard* self, const string& title)
+void WizardImpl::set_title(::mforms::Wizard* self, const std::string& title)
 {
   WizardImpl^ wizard= (WizardImpl^)ObjectImpl::FromUnmanaged(self);
   if (wizard != nullptr)
@@ -100,7 +108,7 @@ void WizardImpl::set_content(::mforms::Wizard* self, ::mforms::View* view)
 
 //--------------------------------------------------------------------------------------------------
 
-void WizardImpl::set_heading(::mforms::Wizard* self, const string& heading)
+void WizardImpl::set_heading(::mforms::Wizard* self, const std::string& heading)
 {
   WizardImpl^ wizard= (WizardImpl^)ObjectImpl::FromUnmanaged(self);
   if (wizard != nullptr)
@@ -154,7 +162,7 @@ void WizardImpl::set_show_extra(::mforms::Wizard* self, bool flag)
 
 //--------------------------------------------------------------------------------------------------
 
-void WizardImpl::set_extra_caption(::mforms::Wizard* self, const string& caption)
+void WizardImpl::set_extra_caption(::mforms::Wizard* self, const std::string& caption)
 {
   WizardImpl^ wizard= (WizardImpl^)ObjectImpl::FromUnmanaged(self);
   if (wizard != nullptr)
@@ -163,7 +171,7 @@ void WizardImpl::set_extra_caption(::mforms::Wizard* self, const string& caption
 
 //--------------------------------------------------------------------------------------------------
 
-void WizardImpl::set_next_caption(::mforms::Wizard* self, const string& caption)
+void WizardImpl::set_next_caption(::mforms::Wizard* self, const std::string& caption)
 {
   WizardImpl^ wizard= (WizardImpl^)ObjectImpl::FromUnmanaged(self);
   if (wizard != nullptr)
@@ -215,7 +223,7 @@ void WizardImpl::setupLayout(mforms::Wizard* wizard)
   _cancel_button = gcnew Button;
   _content = gcnew Panel;
 
-  string icon_path = mforms::App::get()->get_resource_path("wb-wizard-vista-bg.png");
+  std::string icon_path = mforms::App::get()->get_resource_path("wb-wizard-vista-bg.png");
   String^ native_path = gcnew String(icon_path.c_str());
   if (File::Exists(native_path))
     _sidebar_overlay = Image::FromFile(native_path);
@@ -382,7 +390,7 @@ void WizardImpl::resize(Object^ sender, EventArgs^ arguments)
 
 //--------------------------------------------------------------------------------------------------
 
-void WizardImpl::set_title(const string& title)
+void WizardImpl::set_title(const std::string& title)
 {
   Form^ form = get_control<Form>();
   form->Text = CppStringToNative(title);
@@ -438,7 +446,7 @@ void WizardImpl::set_content(::mforms::View *view)
 
 //--------------------------------------------------------------------------------------------------
 
-void WizardImpl::set_heading(const string& heading)
+void WizardImpl::set_heading(const std::string& heading)
 {
   _title->Text= CppStringToNative(heading);
 }
@@ -526,14 +534,14 @@ void WizardImpl::set_show_extra(bool flag)
 
 //--------------------------------------------------------------------------------------------------
 
-void WizardImpl::set_extra_caption(const string& caption)
+void WizardImpl::set_extra_caption(const std::string& caption)
 {
   _extra_button->Text= CppStringToNative(caption);
 }
 
 //--------------------------------------------------------------------------------------------------
 
-void WizardImpl::set_next_caption(const string& caption)
+void WizardImpl::set_next_caption(const std::string& caption)
 {
   if (caption.size() == 0)
     _next_button->Text= "&Next";
