@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2009, 2010, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2009, 2012, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -20,9 +20,6 @@
 #ifndef _GRTPP_MODULE_PYTHON_H_
 #define _GRTPP_MODULE_PYTHON_H_
 
-
-#ifdef ENABLE_PYTHON_MODULES
-
 #include "python_context.h"
 
 #include "grtpp.h"
@@ -43,14 +40,14 @@ namespace grt {
   protected:
     PyObject *_module;
     
-    ValueRef call_function(const BaseListRef &args, PyObject *function, const Function &funcdef);
+    virtual ValueRef call_function(const BaseListRef &args, PyObject *function, const Function &funcdef);
   };
   
   
   class MYSQLGRT_PUBLIC PythonModuleLoader : public ModuleLoader
   {
   public:
-    PythonModuleLoader(GRT *grt);
+    PythonModuleLoader(GRT *grt, const std::string &module_path);
     virtual ~PythonModuleLoader();
     
     virtual std::string get_loader_name() { return LanguagePython; }
@@ -76,6 +73,5 @@ namespace grt {
   
   
 };
-#endif
 
 #endif
