@@ -20,35 +20,10 @@
 #include "tut_stdafx.h"
 
 #include "testgrt.h"
-#include "grt_test_utility.h"
-#include "grt/grt_manager.h"
-#include "grtpp.h"
-
-#include "grts/structs.h"
-#include "grts/structs.workbench.h"
-#include "grts/structs.db.mgmt.h"
-#include "grts/structs.db.mysql.h"
-#include "grts/structs.db.mgmt.h"
-
-#include "cppdbc.h"
 #include "db_rev_eng_be.h"
-
-#include "grtsqlparser/sql_facade.h"
 #include "module_db_mysql.h"
 
-#include "diffchange.h"
-#include "grtdiff.h"
-#include "changeobjects.h"
 #include "changelistobjects.h"
-#include "grtdb/diff_dbobjectmatch.h"
-#include "../../library/sql-parser/source/my_global.h"
-#undef bool
-#include "wb_helpers.h"
-
-#include "myx_statement_parser.h"
-
-#include "myx_statement_parser.h"
-#include "mysql_sql_parser_fe.h"
 
 using namespace std;
 using namespace tut;
@@ -80,6 +55,11 @@ protected:
       // init datatypes
       populate_grt(tester.grt, NULL, tester);
 
+      std::string target_version = tester.wb->get_grt_manager()->get_app_option_string("DefaultTargetMySQLVersion");
+      if (target_version.empty())
+        target_version = "5.5";
+      tester.get_rdbms()->version(CatalogHelper::parse_version(tester.grt, target_version));
+
       // init database connection
       connection= tester.create_connection_for_import();
 
@@ -1263,6 +1243,14 @@ TEST_FUNCTION(6)
 
     grt::NormalizedComparer normalizer(tester.grt);
     normalizer.init_omf(&omf);
+    grt::ValueRef default_engine = tester.wb->get_grt_manager()->get_app_option("db.mysql.Table:tableEngine");
+    std::string default_engine_name;
+    if(grt::StringRef::can_wrap(default_engine))
+        default_engine_name = grt::StringRef::cast_from(default_engine);
+
+    bec::CatalogHelper::apply_defaults(mod_cat, default_engine_name);
+    bec::CatalogHelper::apply_defaults(org_cat, default_engine_name);
+
     alter_change= diff_make(org_cat, mod_cat, &omf);
     ensure("Empty alter:",alter_change);
 
@@ -1335,7 +1323,8 @@ TEST_FUNCTION(6)
     {
         empty_change->dump_log(0);
         alter_map.clear();
-        diffsql_module->generateSQL(mod_cat, options, alter_change);
+        alter_object_list.clear();
+        diffsql_module->generateSQL(mod_cat, options, empty_change);
         diffsql_module->makeSQLSyncScript(options, alter_map, alter_object_list);
         std::cout<<"Iteration:"<<i<<std::endl;
         std::cout<<export_sql_script<<std::endl;
@@ -1408,6 +1397,15 @@ TEST_FUNCTION(7)
 
     grt::NormalizedComparer normalizer(tester.grt);
     normalizer.init_omf(&omf);
+        grt::ValueRef default_engine = tester.wb->get_grt_manager()->get_app_option("db.mysql.Table:tableEngine");
+    std::string default_engine_name;
+    if(grt::StringRef::can_wrap(default_engine))
+        default_engine_name = grt::StringRef::cast_from(default_engine);
+
+    bec::CatalogHelper::apply_defaults(mod_cat, default_engine_name);
+    bec::CatalogHelper::apply_defaults(org_cat, default_engine_name);
+
+
     alter_change= diff_make(org_cat, mod_cat, &omf);
     ensure("Empty alter:",alter_change);
 
