@@ -19,30 +19,8 @@
 
 #include "tut_stdafx.h"
 
-#ifndef _WIN32
-#include <sstream>
-#include <fstream>
-#endif
-
-#ifndef NL
-#if !defined(__WIN__) && !defined(_WIN32) && !defined(_WIN64)
-#define NL "\n"
-#define NLNL "\n\n"
-#else
-#define NL "\r\n"
-#define NLNL "\r\n\r\n"
-#endif
-#endif
-
-#include "testgrt.h"
 #include "grt_test_utility.h"
-#include "grts/structs.db.mgmt.h"
-#include "grts/structs.db.mysql.h"
-#include "grts/structs.workbench.h"
-#include "grts/structs.workbench.physical.h"
-#include "grt/grt_manager.h"
 #include "wb_module_validation_mysql.h"
-#include "grtdb/db_object_helpers.h"
 #include "wb_helpers.h"
 
 using namespace std;
