@@ -19,6 +19,8 @@
 
 #include "stdafx.h"
 
+#include "base/log.h"
+
 #include "diff/diffchange.h"
 #include "diff/grtdiff.h"
 #include "diff/changeobjects.h"
@@ -33,6 +35,8 @@
 #include "grtdb/catalog_templates.h"
 #include "module_db_mysql_shared_code.h"
 
+DEFAULT_LOG_DOMAIN("difftree");
+
 //using namespace wb;
 using namespace bec;
 
@@ -95,7 +99,8 @@ namespace
         get_old_object_name_for_key(node->get_db_part().get_object(), _case_sensitive));
 
       return (name.compare(node_name) == 0);
-      }else if(node->get_model_part().is_valid_object())
+      }
+      else if(node->get_model_part().is_valid_object())
       {
       std::string node_name(
         get_old_object_name_for_key(node->get_model_part().get_object(), _case_sensitive));
@@ -107,6 +112,27 @@ namespace
   };
 }
 
+
+void DiffNode::dump(int depth)
+{
+  const char *dir = NULL;
+  switch (applyDirection)
+  {
+    case ApplyToModel: dir = "model->";
+    case ApplyToDb: dir = "<-db";
+    case DontApply: dir = "ignore";
+    case CantApply: dir = "n/a";
+  }
+
+  log_debug("%*s: %s: %s | %s | %s\n", depth, "-", change ? change->get_type_name().c_str() : "nil",
+            db_part.is_valid_object() ? db_part.get_name().c_str() : "nil",
+            dir,
+            model_part.is_valid_object() ? model_part.get_name().c_str() : "nil");
+  for (DiffNodeVector::iterator It = children.begin();  It != children.end(); ++It)
+    (*It)->dump(depth+1);
+}
+
+
 DiffNode *DiffNode::find_child_by_db_part_name(const std::string& name)
 {
 
