@@ -231,4 +231,8 @@ grtui::WizardPlugin *createExportALTERScriptWizard(grt::Module *module, db_Catal
 }
 
 //--------------------------------------------------------------------------------
-
+void deleteExportALTERScriptWizard (grtui::WizardPlugin *plugin)
+{
+    delete plugin;
+}
+//--------------------------------------------------------------------------------
\ No newline at end of file
