@@ -1,4 +1,4 @@
-# Copyright (c) 2007, 2012, Oracle and/or its affiliates. All rights reserved.
+# Copyright (c) 2007, 2013, Oracle and/or its affiliates. All rights reserved.
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License as
@@ -15,11 +15,12 @@
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 # 02110-1301  USA
 
+import os
 import re
+import socket
+import threading
 import time
 import Queue
-import threading
-import os
 import StringIO
 
 import wb_admin_utils
@@ -27,7 +28,7 @@ from workbench.utils import server_version_str2tuple
 from wb_admin_ssh import SSHDownException
 from workbench.db_utils import MySQLConnection, MySQLError, QueryError
 
-from wb_common import OperationCancelledError, Users
+from wb_common import OperationCancelledError, Users, PermissionDeniedError, InvalidPasswordError
 
 from wb_server_control import PasswordHandler, ServerControlShell, ServerControlWMI
 from wb_server_management import ServerManagementHelper, SSH
@@ -593,19 +594,23 @@ uses_ssh: %i uses_wmi: %i\n""" % (self.server_profile.uses_ssh, self.server_prof
         def get_config_options():
             if self.server_profile.config_file_path:
                 try:
-                    cfg_file = open(self.server_profile.config_file_path)
-                except IOError:
-                    # FIXME: May return False if permission is not granted to execute os.stat() on the requested file,
-                    #        even if the path physically exists and is therefore still readable by admin:
-                    if os.path.isfile(self.server_profile.config_file_path):
-                        password = self.server_control.get_password()
-                        command = 'type %s' if self.server_profile.target_is_windows else 'cat %s'
-                        self.cfg_data = self.execute_filtered_command(command % self.server_profile.config_file_path,
-                                                                      as_user = Users.ADMIN,
-                                                                      user_password = password)[0]
-                        cfg_file = StringIO.StringIO(self.cfg_data)
-                    else:
-                        return {}
+                    cfg_file = StringIO.StringIO(self.server_helper.get_file_content(self.server_profile.config_file_path))
+                except PermissionDeniedError:
+                    log_debug(_this_file, 'Could not open the file "%s" as the current user. Trying as admin' % self.server_profile.config_file_path)
+                    while True:
+                        try:
+                            password = self.password_handler.get_password_for('file')
+                            cfg_file = StringIO.StringIO(self.server_helper.get_file_content(self.server_profile.config_file_path,
+                                              as_user=Users.ADMIN, user_password = password))
+                            break
+                        except InvalidPasswordError:
+                            self.password_handler.reset_password_for('file')
+                        except Exception, err:
+                            log_error(_this_file, 'Could not open the file "%s": %s' % (self.server_profile.config_file_path, str(err)))
+                            return {}
+                except Exception, err:
+                    log_error(_this_file, 'Could not open the file "%s": %s' % (self.server_profile.config_file_path, str(err)))
+                    return {}
 
                 opts = {}
                 section = 'root'
@@ -662,25 +667,30 @@ uses_ssh: %i uses_wmi: %i\n""" % (self.server_profile.uses_ssh, self.server_prof
             config_section = self.server_profile.config_file_section or 'mysqld'
 
             request_save_profile = False
+
+            hostname = self.get_server_variable('hostname', '')
+            if not hostname and self.server_profile.is_local:
+                hostname = socket.gethostname()
+
+            datadir = self.get_server_variable('datadir', '')
+            if datadir and self.server_profile.datadir != datadir:
+                self.server_profile.datadir = datadir
+                request_save_profile = True
+
+            basedir = self.get_server_variable('basedir', '')
+            if basedir and self.server_profile.basedir != basedir:
+                self.server_profile.basedir = basedir
+                request_save_profile = True
+
             try:
-                hostname = self.get_server_variable('hostname')
-
-
-                datadir = self.get_server_variable('datadir')
-                if self.server_profile.datadir != datadir:
-                    self.server_profile.datadir = datadir
-                    request_save_profile = True
-
-                basedir = self.get_server_variable('basedir')
-                if self.server_profile.basedir != basedir:
-                    self.server_profile.basedir = basedir
-                    request_save_profile = True
-
                 general_log_enabled = self.get_server_variable('general_log') in ('ON', '1')
                 if self.server_profile.general_log_enabled != general_log_enabled:
                     self.server_profile.general_log_enabled = general_log_enabled
                     request_save_profile = True
+            except ValueError:
+                pass
 
+            try:
                 slow_log_enabled = self.get_server_variable('log_slow_queries') in ('ON', '1')
                 if self.server_profile.slow_log_enabled != slow_log_enabled:
                     self.server_profile.slow_log_enabled = slow_log_enabled
@@ -690,13 +700,19 @@ uses_ssh: %i uses_wmi: %i\n""" % (self.server_profile.uses_ssh, self.server_prof
 
             if self.server_version < (5, 1, 29):
                 general_log_file_path = opts[config_section].get('log', '').strip(' "') if opts.has_key(config_section) else ''
-                self.server_profile.general_log_file_path = general_log_file_path or os.path.join(datadir, hostname + '.log')
+                if self.server_profile.general_log_file_path != general_log_file_path:
+                    self.server_profile.general_log_file_path = general_log_file_path or os.path.join(self.server_profile.datadir, hostname + '.log')
+                    request_save_profile = True
 
                 slow_query_log_file = opts[config_section].get('log-slow-queries', '').strip(' "') if opts.has_key(config_section) else ''
-                self.server_profile.slow_log_file_path = slow_query_log_file or os.path.join(datadir, hostname + '.slow')
+                if self.server_profile.slow_log_file_path != slow_query_log_file:
+                    self.server_profile.slow_log_file_path = slow_query_log_file or os.path.join(self.server_profile.datadir, hostname + '.slow')
+                    request_save_profile = True
 
                 error_log_file_path = opts[config_section].get('log-error', '').strip(' "') if opts.has_key(config_section) else ''
-                self.server_profile.error_log_file_path = error_log_file_path or os.path.join(datadir, hostname + '.err')
+                if self.server_profile.error_log_file_path != error_log_file_path:
+                    self.server_profile.error_log_file_path = error_log_file_path or os.path.join(self.server_profile.datadir, hostname + '.err')
+                    request_save_profile = True
 
             else:
                 path = self.get_server_variable('general_log_file')
