@@ -20,8 +20,12 @@ from __future__ import with_statement
 import platform
 import threading
 import time
+import os
+import sys
 import ConfigParser
 
+from grt import log_info, log_error
+
 from mforms import App, Utilities, newBox, newPanel, newButton, newLabel, newTabView, newTabSwitcher, newTextEntry, newSelector
 from mforms import newTaskSidebar
 import mforms
@@ -101,8 +105,6 @@ class ServerStatusPage(mforms.Box):
     #---------------------------------------------------------------------------
     def refresh(self, status):
         self.status.refresh_status(status)
-        if status and self.connections:
-            self.connections.refresh_mt(self.ctrl_be)
 
     #---------------------------------------------------------------------------
     def page_activated(self):
@@ -219,8 +221,7 @@ class WbAdminMainView(mforms.Box):
         self.dump = WbAdminExport(server_profile, self.ctrl_be, self)
         self.restore = WbAdminImport(server_profile, self.ctrl_be, self)
 
-        #from wb_admin_meb import WbAdminEnterpriseBackup
-        #self.meb = WbAdminEnterpriseBackup(server_profile, self.ctrl_be, self)
+        self.init_extensions(server_profile, self.ctrl_be)
 
         Utilities.add_timeout(0.5, weakcb(self, "timeout"))
         self.timeout_thread = threading.Thread(target = self.refresh_tasks_thread)
@@ -380,8 +381,47 @@ class WbAdminMainView(mforms.Box):
 
         self.tasks_side.add_section_entry(section_name, item_name, icon_name_as_cmd + ".png", icon_name_as_cmd, False)
         i = self.tabview.add_page(container, "")
-        content.set_padding(8)
+        #content.set_padding(8)
         self.tabs.append(content)
         self.name2page[icon_name_as_cmd] = (i, content)
 
         return container
+
+    #---------------------------------------------------------------------------
+    def init_extensions(self, server_profile, ctrl_be):
+        log_info("WBA", "Initializing extension modules for WBA...\n")
+
+        init_count = 0
+        # search in the same dir where the WBA code itself is located
+        for location in [os.path.dirname(__file__)]:
+            try:
+                folders = [f for f in os.listdir(location) if f.startswith("wba_") and os.path.isdir(os.path.join(location, f))]
+            except:
+                continue
+
+            sys.path.append(location)
+
+            for candidate in folders:
+                if os.path.exists(os.path.join(location, candidate, "__init__.py")):
+                    mod = __import__(candidate)
+                    if hasattr(mod, "wba_register"):
+                        log_info("WBA", "Registering WBA extension module %s/%s...\n" % (location, candidate))
+                        try:
+                            mod.wba_register(server_profile, ctrl_be, self)
+                            init_count += 1
+                            log_info("WBA", "WBA extension module %s/%s registered OK\n" % (location, candidate))
+                        except:
+                            import traceback
+                            traceback.print_exc()
+                            log_error("WBA", "Exception caught while loading WBA extension module %s/%s\n" % (location, candidate))
+                            del sys.modules[mod.__name__]
+                            del mod
+                    else:
+                        # unload the module
+                        del sys.modules[mod.__name__]
+                        del mod
+
+            sys.path.pop()
+
+        log_info("WBA", "%i extension modules initialized\n" % init_count)
+
