@@ -25,6 +25,7 @@ struct = { 'Advanced': { 'General': { 'default_week_format': 'server',
                                              'delayed_queue_size': 'server',
                                              'max_delayed_threads': 'server'},
                 'Localization': { 'default-character-set': 'server',
+                                  'default-collation': 'server',
                                   'default-time-zone': 'server',
                                   'language': 'server'},
                 'Thread specific settings': { 'one-thread': 'server',
@@ -40,6 +41,8 @@ struct = { 'Advanced': { 'General': { 'default_week_format': 'server',
                              'big-tables': 'server',
                              'bind-address': 'server',
                              'binlog_cache_size': 'binlog',
+                             'binlog_stmt_cache_size': 'binlog',
+                             'max_binlog_stmt_cache_size': 'binlog',
                              'binlog_direct_non_transactional_updates': 'binlog',
                              'bulk_insert_buffer_size': 'myisam',
                              'chroot': 'security',
@@ -89,7 +92,7 @@ struct = { 'Advanced': { 'General': { 'default_week_format': 'server',
                                 'tmpdir': 'server'},
                'General': {
                             'console': 'server',
-                            'datetime_format': 'server',
+                            #'datetime_format': 'server',  it seem the option was removed from cnf
                             'debug-sync-timeout': 'server',
                             'default-storage-engine': 'server',
                             'default-table-type': 'server',
@@ -101,7 +104,7 @@ struct = { 'Advanced': { 'General': { 'default_week_format': 'server',
                             'port-open-timeout': 'server',
                             'skip-character-set-client-handshake': 'server',
                             'standalone': 'server',
-                            'time_format': 'server',
+                            #'time_format': 'server', it seems the option was removed from cnf
                             'verbose': 'server',
                             'character-set-client-handshake': 'server',
                             'character-set-filesystem': 'server',
@@ -119,7 +122,8 @@ struct = { 'Advanced': { 'General': { 'default_week_format': 'server',
                          'Datafiles': { 'innodb_data_file_path': 'innodb',
                                         'innodb_data_home_dir': 'innodb',
                                         'innodb_file_per_table': 'innodb'},
-                         'General': { 'ignore-builtin-innodb': 'server',
+                         'General': { 'autocommit': 'server',
+                                      'ignore-builtin-innodb': 'server',
                                       'innodb_adaptive_flushing': 'innodb',
                                       'innodb_adaptive_hash_index': 'innodb',
                                       'innodb_autoextend_increment': 'innodb',
@@ -168,7 +172,9 @@ struct = { 'Advanced': { 'General': { 'default_week_format': 'server',
                                        },
                          'Memory': { 'innodb_additional_mem_pool_size': 'innodb',
                                      'innodb_buffer_pool_awe_mem_mb': 'innodb',
-                                     'innodb_buffer_pool_size': 'innodb'},
+                                     'innodb_buffer_pool_size': 'innodb',
+                                     'innodb_buffer_pool_instances': 'innodb'
+                                     },
                          'Various': { 'innodb_fast_shutdown': 'innodb',
                                       'innodb_file_io_threads': 'innodb',
                                       'innodb_force_recovery': 'innodb',
@@ -303,10 +309,14 @@ struct = { 'Advanced': { 'General': { 'default_week_format': 'server',
                                             'performance_schema_max_table_handles' : 'perfschema',
                                             'performance_schema_max_table_instances' : 'perfschema',
                                             'performance_schema_max_thread_classes' : 'perfschema',
-                                            'performance_schema_max_thread_instances' : 'perfschema'
+                                            'performance_schema_max_thread_instances' : 'perfschema',
+                                            'performance_schema_setup_actors_size': 'perfschema',
+                                            'performance_schema_setup_objects_size': 'perfschema'
                                           }
                  },
-  'Replication': { 'General': { 'server-id': 'server'},
+  'Replication': { 'General': { 'server-id': 'server',
+                                'init-rpl-role': 'server'
+                              },
                    'General slave': { 'abort-slave-event-count': 'replication',
                                       'disconnect-slave-event-count': 'replication',
                                       'log-slave-updates': 'replication',
@@ -324,7 +334,7 @@ struct = { 'Advanced': { 'General': { 'default_week_format': 'server',
                    'Relay Log': { 'max_relay_log_size': 'server',
                                   'relay-log': 'replication',
                                   'relay-log-index': 'replication',
-                                  'relay-log-info-file': 'server',
+                                  'relay_log_info_file': 'server',
                                   'relay_log_purge': 'replication',
                                   'relay_log_space_limit': 'server'},
                    'Slave Identification': { 'report-host': 'replication',
