@@ -195,7 +195,7 @@ void WBPrintOperation::on_begin_print(const Glib::RefPtr<Gtk::PrintContext>& ctx
   }
 
   // size of the printable area in cairo coords
-  mdc::Size pageSize;
+  base::Size pageSize;
   pageSize.width= paperWidth - marginLeft - marginRight;
   pageSize.height= paperHeight - marginTop - marginBottom;
   
